/*
 *  image.h -- part of stereographic2platecarree
 *
 *  Copyright (c) 2010 Marc Pegon <pe.marc@free.fr>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef IMAGE_H_
#define IMAGE_H_

#include <stdint.h>

// For now, supported images are RGB32

typedef struct s_Image {
    uint8_t bytesPerComponent;
    uint32_t *data;
    uint32_t width;
    uint32_t height;
} Image;

// Requires *img exists and is empty (hasn't been created yet or has been deleted)
void createUninitializedImage(Image *img, uint32_t width, uint32_t height);

// Requires *img exists and is empty
// Created an image filled  with given color
void createImage(Image *img, uint32_t width, uint32_t height, uint32_t color);

// Requires img has been created
// Fills the image with given color
void fillImage(Image img, uint32_t color);

// Requires img isn't empty
void deleteImage(Image img);

// Get pixel at (x, y) in the image
// Warning : the function won't check that (x, y) is inside the image !
uint32_t igetPixel(Image img, uint32_t x, uint32_t y);

uint32_t mixPixels(uint32_t p1, double weight1, uint32_t p2, double weight2);

// Get pixel at floating point (x, y) by mixing pixels around
// If (x, y) is outside the image, the function will guess the color here by repeating the pixels at the image's border
uint32_t fgetPixel(Image img, double x, double y);

#endif // SIMAGE_H_
