/*
 *  macros.h -- part of stereographic2platecarree
 *
 *  Copyright (c) 2010 Marc Pegon <pe.marc@free.fr>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef _MACROS_H_
#define _MACROS_H_

#include <stdlib.h>
#include <stdio.h>

enum {T_QUIET = 0, T_NORMAL, T_VERBOSE};

int debug;
int traceLevel;

// added line (void)NULL to force the user to put a ";" after calling error
#define info_trace(msg_trace,...) \
        if (msg_trace <= traceLevel) { \
            if (debug) { \
                printf("[%s: %s, l.%d] ", __FILE__, __func__, __LINE__); \
            } \
            printf(__VA_ARGS__); \
        }

#define error_trace(...) \
        if (debug) { \
            printf("[%s: %s, l.%d] ", __FILE__, __func__, __LINE__); \
        } \
        printf(__VA_ARGS__); \
        exit(EXIT_FAILURE)

// common errors
#define read_error(fileName) error_trace("Error occured when reading file %s.\n", fileName)
#define write_error(fileName) error_trace("Error occured when writing in file %s.\n", fileName)
#define open_error(fileName) error_trace("Error occured when opening file %s.\n", fileName)
#define close_error(fileName) error_trace("Error occured when closing file %s.\n", fileName)

#ifdef DEBUG
    #define debug(...)\
        (void)
#else
    #define debug(...)\
        printf(__VA_ARGS__)
#endif // DEBUG

#define GET8_B(x) (x & 0x000000FF)
#define GET8_G(x) ((x & 0x0000FF00) >> 8)
#define GET8_R(x) ((x & 0x00FF0000) >> 16)

#endif
